<?php
class ControllerCatalogInformationCategory extends Controller {
	private $error = array();

	public function index() {
		$this->load->language('catalog/information_category');

		$this->document->setTitle($this->language->get('heading_title'));

		$this->load->model('catalog/information_category');

		$this->getList();
	}

	public function add() {
		$this->load->language('catalog/information_category');

		$this->document->setTitle($this->language->get('heading_title'));

		$this->load->model('catalog/information_category');

		if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validateForm()) {
			$this->model_catalog_information_category->addCategory($this->request->post);

			$this->session->data['success'] = $this->language->get('text_success');

			$url = '';

			if (isset($this->request->get['sort'])) {
				$url .= '&sort=' . $this->request->get['sort'];
			}

			if (isset($this->request->get['order'])) {
				$url .= '&order=' . $this->request->get['order'];
			}

			if (isset($this->request->get['page'])) {
				$url .= '&page=' . $this->request->get['page'];
			}

			$this->response->redirect($this->url->link('catalog/information_category', 'token=' . $this->session->data['token'] . $url, 'SSL'));
		}

		$this->getForm();
	}

	public function edit() {
		$this->load->language('catalog/information_category');

		$this->document->setTitle($this->language->get('heading_title'));

		$this->load->model('catalog/information_category');

		if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validateForm()) {
			$this->model_catalog_information_category->editCategory($this->request->get['category_id'], $this->request->post);

			$this->session->data['success'] = $this->language->get('text_success');

			$url = '';

			if (isset($this->request->get['sort'])) {
				$url .= '&sort=' . $this->request->get['sort'];
			}

			if (isset($this->request->get['order'])) {
				$url .= '&order=' . $this->request->get['order'];
			}

			if (isset($this->request->get['page'])) {
				$url .= '&page=' . $this->request->get['page'];
			}

			$this->response->redirect($this->url->link('catalog/information_category', 'token=' . $this->session->data['token'] . $url, 'SSL'));
		}

		$this->getForm();
	}

	public function delete() {
		$this->load->language('catalog/information_category');

		$this->document->setTitle($this->language->get('heading_title'));

		$this->load->model('catalog/information_category');

		if (isset($this->request->post['selected']) && $this->validateDelete()) {
			foreach ($this->request->post['selected'] as $category_id) {
				$this->model_catalog_information_category->deleteCategory($category_id);
			}

			$this->session->data['success'] = $this->language->get('text_success');

			$url = '';

			if (isset($this->request->get['sort'])) {
				$url .= '&sort=' . $this->request->get['sort'];
			}

			if (isset($this->request->get['order'])) {
				$url .= '&order=' . $this->request->get['order'];
			}

			if (isset($this->request->get['page'])) {
				$url .= '&page=' . $this->request->get['page'];
			}

			$this->response->redirect($this->url->link('catalog/information_category', 'token=' . $this->session->data['token'] . $url, 'SSL'));
		}

		$this->getList();
	}

	public function repair() {
		$this->load->language('catalog/information_category');

		$this->document->setTitle($this->language->get('heading_title'));

		$this->load->model('catalog/information_category');

		if ($this->validateRepair()) {
			$this->model_catalog_information_category->repairCategories();

			$this->session->data['success'] = $this->language->get('text_success');

			$this->response->redirect($this->url->link('catalog/information_category', 'token=' . $this->session->data['token'], 'SSL'));
		}

		$this->getList();
	}

	protected function getList() {
		if (isset($this->request->get['sort'])) {
			$sort = $this->request->get['sort'];
		} else {
			$sort = 'name';
		}

		if (isset($this->request->get['order'])) {
			$order = $this->request->get['order'];
		} else {
			$order = 'ASC';
		}

		if (isset($this->request->get['page'])) {
			$page = $this->request->get['page'];
		} else {
			$page = 1;
		}

		$url = '';

		if (isset($this->request->get['sort'])) {
			$url .= '&sort=' . $this->request->get['sort'];
		}

		if (isset($this->request->get['order'])) {
			$url .= '&order=' . $this->request->get['order'];
		}

		if (isset($this->request->get['page'])) {
			$url .= '&page=' . $this->request->get['page'];
		}
		
		$data['breadcrumbs'] = array();

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('text_home'),
			'href' => $this->url->link('common/dashboard', 'token=' . $this->session->data['token'], 'SSL')
		);

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('heading_title'),
			'href' => $this->url->link('catalog/information_category', 'token=' . $this->session->data['token'] . $url, 'SSL')
		);
		
		$data['insert'] = $this->url->link('catalog/information_category/add', 'token=' . $this->session->data['token'] . $url, 'SSL');
		$data['delete'] = $this->url->link('catalog/information_category/delete', 'token=' . $this->session->data['token'] . $url, 'SSL');
		$data['repair'] = $this->url->link('catalog/information_category/repair', 'token=' . $this->session->data['token'] . $url, 'SSL');

		$data['categories'] = array();

		$filter_data = array(
			'sort'  => $sort,
			'order' => $order,
			'start' => ($page - 1) * $this->config->get('config_limit_admin'),
			'limit' => $this->config->get('config_limit_admin')
		);

		$category_total = $this->model_catalog_information_category->getTotalCategories();

		$results = $this->model_catalog_information_category->getCategories($filter_data);

		foreach ($results as $result) {
			$data['categories'][] = array(
				'category_id' => $result['category_id'],
				'name'        => $result['name'],
				'sort_order'  => $result['sort_order'],
				'edit'        => $this->url->link('catalog/information_category/edit', 'token=' . $this->session->data['token'] . '&category_id=' . $result['category_id'] . $url, 'SSL'),
				'delete'      => $this->url->link('catalog/information_category/delete', 'token=' . $this->session->data['token'] . '&category_id=' . $result['category_id'] . $url, 'SSL')
			);
		}

		$data['heading_title'] = $this->language->get('heading_title');

		$data['text_list'] = $this->language->get('text_list');
		$data['text_no_results'] = $this->language->get('text_no_results');
		$data['text_confirm'] = $this->language->get('text_confirm');

		$data['column_name'] = $this->language->get('column_name');
		$data['column_sort_order'] = $this->language->get('column_sort_order');
		$data['column_action'] = $this->language->get('column_action');

		$data['button_insert'] = $this->language->get('button_insert');
		$data['button_edit'] = $this->language->get('button_edit');
		$data['button_delete'] = $this->language->get('button_delete');
		$data['button_rebuild'] = $this->language->get('button_rebuild');

		if (isset($this->error['warning'])) {
			$data['error_warning'] = $this->error['warning'];
		} else {
			$data['error_warning'] = '';
		}

		if (isset($this->session->data['success'])) {
			$data['success'] = $this->session->data['success'];

			unset($this->session->data['success']);
		} else {
			$data['success'] = '';
		}

		if (isset($this->request->post['selected'])) {
			$data['selected'] = (array)$this->request->post['selected'];
		} else {
			$data['selected'] = array();
		}

		$url = '';

		if ($order == 'ASC') {
			$url .= '&order=DESC';
		} else {
			$url .= '&order=ASC';
		}

		if (isset($this->request->get['page'])) {
			$url .= '&page=' . $this->request->get['page'];
		}

		$data['sort_name'] = $this->url->link('catalog/information_category', 'token=' . $this->session->data['token'] . '&sort=name' . $url, 'SSL');
		$data['sort_sort_order'] = $this->url->link('catalog/information_category', 'token=' . $this->session->data['token'] . '&sort=sort_order' . $url, 'SSL');

		$url = '';

		if (isset($this->request->get['sort'])) {
			$url .= '&sort=' . $this->request->get['sort'];
		}

		if (isset($this->request->get['order'])) {
			$url .= '&order=' . $this->request->get['order'];
		}

		$pagination = new Pagination();
		$pagination->total = $category_total;
		$pagination->page = $page;
		$pagination->limit = $this->config->get('config_limit_admin');
		$pagination->url = $this->url->link('catalog/information_category', 'token=' . $this->session->data['token'] . $url . '&page={page}', 'SSL');

		$data['pagination'] = $pagination->render();

		$data['results'] = sprintf($this->language->get('text_pagination'), ($category_total) ? (($page - 1) * $this->config->get('config_limit_admin')) + 1 : 0, ((($page - 1) * $this->config->get('config_limit_admin')) > ($category_total - $this->config->get('config_limit_admin'))) ? $category_total : ((($page - 1) * $this->config->get('config_limit_admin')) + $this->config->get('config_limit_admin')), $category_total, ceil($category_total / $this->config->get('config_limit_admin')));

		$data['sort'] = $sort;
		$data['order'] = $order;

		$data['header'] = $this->load->controller('common/header');
		$data['column_left'] = $this->load->controller('common/column_left');
		$data['footer'] = $this->load->controller('common/footer');

		$this->response->setOutput($this->load->view('catalog/information_category_list.tpl', $data));
	}

	protected function getForm() {
		$data['heading_title'] = $this->language->get('heading_title');
		
		$data['text_form'] = !isset($this->request->get['category_id']) ? $this->language->get('text_add') : $this->language->get('text_edit');
		$data['text_none'] = $this->language->get('text_none');
		$data['text_default'] = $this->language->get('text_default');
		$data['text_enabled'] = $this->language->get('text_enabled');
		$data['text_disabled'] = $this->language->get('text_disabled');
    $data['text_show_downloads'] = $this->language->get('text_show_downloads');
    
    $data['entry_name'] = $this->language->get('entry_name');
		$data['entry_description'] = $this->language->get('entry_description');
		$data['entry_meta_title'] = $this->language->get('entry_meta_title');
		$data['entry_meta_description'] = $this->language->get('entry_meta_description');
		$data['entry_meta_keyword'] = $this->language->get('entry_meta_keyword');
		$data['entry_keyword'] = $this->language->get('entry_keyword');
		$data['entry_parent'] = $this->language->get('entry_parent');
		$data['entry_store'] = $this->language->get('entry_store');
		$data['entry_image'] = $this->language->get('entry_image');
		$data['entry_sort_order'] = $this->language->get('entry_sort_order');
		$data['entry_status'] = $this->language->get('entry_status');
		$data['entry_layout'] = $this->language->get('entry_layout');
    
    $data['entry_simple_items'] = $this->language->get('entry_simple_items');
    $data['entry_simple_subcategories'] = $this->language->get('entry_simple_subcategories');
    $data['entry_target_link'] = $this->language->get('entry_target_link');
    $data['entry_this_link'] = $this->language->get('entry_this_link');
    $data['entry_default_sort_order'] = $this->language->get('entry_default_sort_order');
    $data['entry_show_downloads'] = $this->language->get('entry_show_downloads');
    $data['entry_show_item_date'] = $this->language->get('entry_show_item_date');
    
    $data['entry_allowed_groups'] = $this->language->get('entry_allowed_groups');
    $data['entry_denied_groups'] = $this->language->get('entry_denied_groups');
    $data['entry_allowed_users'] = $this->language->get('entry_allowed_users');
    $data['entry_denied_users'] = $this->language->get('entry_denied_users');
    
    $data['entry_special'] = $this->language->get('entry_special');

    $data['help_special'] = $this->language->get('help_special');
		$data['help_auto'] = $this->language->get('help_auto');
		$data['help_keyword'] = $this->language->get('help_keyword');
    
    $data['help_link'] = $this->language->get('help_link');
    $data['help_simple_items'] = $this->language->get('help_simple_items');
    $data['help_simple_subcategories'] = $this->language->get('help_simple_subcategories');
    $data['help_this_link'] = $this->language->get('help_this_link');
		$data['help_show_downloads'] = $this->language->get('help_show_downloads');

		$data['button_save'] = $this->language->get('button_save');
		$data['button_cancel'] = $this->language->get('button_cancel');

		$data['tab_general'] = $this->language->get('tab_general');
		$data['tab_data'] = $this->language->get('tab_data');
		$data['tab_design'] = $this->language->get('tab_design');
    $data['tab_rights'] = $this->language->get('tab_rights');

		if (isset($this->error['warning'])) {
			$data['error_warning'] = $this->error['warning'];
		} else {
			$data['error_warning'] = '';
		}

		if (isset($this->error['name'])) {
			$data['error_name'] = $this->error['name'];
		} else {
			$data['error_name'] = array();
		}

		if (isset($this->error['meta_title'])) {
			$data['error_meta_title'] = $this->error['meta_title'];
		} else {
			$data['error_meta_title'] = array();
		}
    
    if (isset($this->error['keyword'])) {
			$data['error_keyword'] = $this->error['keyword'];
		} else {
			$data['error_keyword'] = '';
		}

		$url = '';

		if (isset($this->request->get['sort'])) {
			$url .= '&sort=' . $this->request->get['sort'];
		}

		if (isset($this->request->get['order'])) {
			$url .= '&order=' . $this->request->get['order'];
		}

		if (isset($this->request->get['page'])) {
			$url .= '&page=' . $this->request->get['page'];
		}
		
		$data['breadcrumbs'] = array();

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('text_home'),
			'href' => $this->url->link('common/dashboard', 'token=' . $this->session->data['token'], 'SSL')
		);

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('heading_title'),
			'href' => $this->url->link('catalog/information_category', 'token=' . $this->session->data['token'] . $url, 'SSL')
		);
		
		if (!isset($this->request->get['category_id'])) {
			$data['action'] = $this->url->link('catalog/information_category/add', 'token=' . $this->session->data['token'] . $url, 'SSL');
		} else {
			$data['action'] = $this->url->link('catalog/information_category/edit', 'token=' . $this->session->data['token'] . '&category_id=' . $this->request->get['category_id'] . $url, 'SSL');
		}

		$data['cancel'] = $this->url->link('catalog/information_category', 'token=' . $this->session->data['token'] . $url, 'SSL');

		if (isset($this->request->get['category_id']) && ($this->request->server['REQUEST_METHOD'] != 'POST')) {
			$category_info = $this->model_catalog_information_category->getCategory($this->request->get['category_id']);
		}

		$data['token'] = $this->session->data['token'];

		$this->load->model('localisation/language');

		$data['languages'] = $this->model_localisation_language->getLanguages();

		if (isset($this->request->post['category_description'])) {
			$data['category_description'] = $this->request->post['category_description'];
		} elseif (isset($this->request->get['category_id'])) {
			$data['category_description'] = $this->model_catalog_information_category->getCategoryDescriptions($this->request->get['category_id']);
		} else {
			$data['category_description'] = array();
		}

		if (isset($this->request->post['path'])) {
			$data['path'] = $this->request->post['path'];
		} elseif (!empty($category_info)) {
			$data['path'] = $category_info['path'];
		} else {
			$data['path'] = '';
		}

		if (isset($this->request->post['parent_id'])) {
			$data['parent_id'] = $this->request->post['parent_id'];
		} elseif (!empty($category_info)) {
			$data['parent_id'] = $category_info['parent_id'];
		} else {
			$data['parent_id'] = 0;
		}
    
    $this->load->model('setting/store');

		$data['stores'] = $this->model_setting_store->getStores();
    
 		if (isset($this->request->post['category_store'])) {
			$data['category_store'] = $this->request->post['category_store'];
		} elseif (isset($this->request->get['category_id'])) {
			$data['category_store'] = $this->model_catalog_information_category->getCategoryStores($this->request->get['category_id']);
		} else {
			$data['category_store'] = array(0);
		}

    if (isset($this->request->get['category_id'])) {

      $data['this_links'] = array();
      
      foreach ($data['category_store'] as $site) {
        
        if (!$site) {
          $data['this_links'][] = HTTP_CATALOG . 'index.php?route=information/category&path=' . $this->request->get['category_id'];
        } else {
  			  $result = $this->model_setting_store->getStore($site);
          if ($result) $data['this_links'][] = $result['url'] . 'index.php?route=information/category&path=' . $this->request->get['category_id'];        
        }
  		}
    
    }

		if (isset($this->request->post['keyword'])) {
			$data['keyword'] = $this->request->post['keyword'];
		} elseif (!empty($category_info)) {
			$data['keyword'] = $category_info['keyword'];
		} else {
			$data['keyword'] = '';
		}

		if (isset($this->request->post['image'])) {
			$data['image'] = $this->request->post['image'];
		} elseif (!empty($category_info)) {
			$data['image'] = $category_info['image'];
		} else {
			$data['image'] = '';
		}

		$this->load->model('tool/image');

		if (isset($this->request->post['image']) && is_file(DIR_IMAGE . $this->request->post['image'])) {
			$data['thumb'] = $this->model_tool_image->resize($this->request->post['image'], 100, 100);
		} elseif (!empty($category_info) && is_file(DIR_IMAGE . $category_info['image'])) {
			$data['thumb'] = $this->model_tool_image->resize($category_info['image'], 100, 100);
		} else {
			$data['thumb'] = $this->model_tool_image->resize('no_image.png', 100, 100);
		}

		$data['placeholder'] = $this->model_tool_image->resize('no_image.png', 100, 100);

		if (isset($this->request->post['sort_order'])) {
			$data['sort_order'] = $this->request->post['sort_order'];
		} elseif (!empty($category_info)) {
			$data['sort_order'] = $category_info['sort_order'];
		} else {
			$data['sort_order'] = 0;
		}

		if (isset($this->request->post['status'])) {
			$data['status'] = $this->request->post['status'];
		} elseif (!empty($category_info)) {
			$data['status'] = $category_info['status'];
		} else {
			$data['status'] = 1;
		}
    
    if (isset($this->request->post['special'])) {
			$data['special'] = $this->request->post['special'];
		} elseif (!empty($category_info)) {
			$data['special'] = $category_info['special'];
		} else {
			$data['special'] = 0;
		}

		if (isset($this->request->post['category_layout'])) {
			$data['category_layout'] = $this->request->post['category_layout'];
		} elseif (isset($this->request->get['category_id'])) {
			$data['category_layout'] = $this->model_catalog_information_category->getCategoryLayouts($this->request->get['category_id']);
		} else {
			$data['category_layout'] = array();
		}
    
    if (isset($this->request->post['show_downloads'])) {
			$data['show_downloads'] = $this->request->post['show_downloads'];
		} elseif (!empty($category_info)) {
			$data['show_downloads'] = $category_info['show_downloads'];
		} else {
			$data['show_downloads'] = 0;
		}
    
    if (isset($this->request->post['show_item_date'])) {
			$data['show_item_date'] = $this->request->post['show_item_date'];
		} elseif (!empty($category_info)) {
			$data['show_item_date'] = $category_info['show_item_date'];
		} else {
			$data['show_item_date'] = 0;
		}
    
    if (isset($this->request->post['simple_items'])) {
			$data['simple_items'] = $this->request->post['simple_items'];
		} elseif (!empty($category_info)) {
			$data['simple_items'] = $category_info['simple_items'];
		} else {
			$data['simple_items'] = 0;
		}
    
    if (isset($this->request->post['simple_subcategories'])) {
			$data['simple_subcategories'] = $this->request->post['simple_subcategories'];
		} elseif (!empty($category_info)) {
			$data['simple_subcategories'] = $category_info['simple_subcategories'];
		} else {
			$data['simple_subcategories'] = 0;
		}
    
    if (isset($this->request->post['target_link'])) {
			$data['target_link'] = $this->request->post['target_link'];
		} elseif (!empty($category_info)) {
			$data['target_link'] = $category_info['target_link'];
		} else {
			$data['target_link'] = '';
		}

		$this->load->model('design/layout');

		$data['layouts'] = $this->model_design_layout->getLayouts();

    $this->load->model('setting/rights');
    
    if (isset($this->request->post['allowed_groups'])) {
			$allowed_groups = $this->request->post['allowed_groups'];
		} elseif (isset($this->request->get['category_id'])) {
			$allowed_groups = $this->model_setting_rights->getAllowedGroups($this->request->get['category_id'],2); //2 is information_category type
		} else {
      $allowed_groups[] = -1;
		}
    
    $data['allowed_groups'] = array();
    
    $this->load->model('sale/customer_group');
    
    foreach ($allowed_groups as $group_id) {
			$group_info = $this->model_sale_customer_group->getCustomerGroup($group_id);
 
			if ($group_info) {
				$data['allowed_groups'][] = array(
					'group_id' => $group_info['customer_group_id'],
					'name' => $group_info['name']
				);
			}
		}
    
    if (isset($this->request->post['denied_groups'])) {
			$denied_groups = $this->request->post['denied_groups'];
		} elseif (isset($this->request->get['category_id'])) {
			$denied_groups = $this->model_setting_rights->getDeniedGroups($this->request->get['category_id'],2); //2 is information_category type
		} else {
			$denied_groups = array();
    }
    
    $data['denied_groups'] = array();
    
    foreach ($denied_groups as $group_id) {
			$group_info = $this->model_sale_customer_group->getCustomerGroup($group_id);
 
			if ($group_info) {
				$data['denied_groups'][] = array(
					'group_id' => $group_info['customer_group_id'],
					'name' => $group_info['name']
				);
			}
		}
      
    if (isset($this->request->post['allowed_users'])) {
			$allowed_users = $this->request->post['allowed_users'];
		} elseif (isset($this->request->get['category_id'])) {
			$allowed_users = $this->model_setting_rights->getAllowedUsers($this->request->get['category_id'],2); //2 is information_category type
		} else {
			$allowed_users = array();
		}
    
    $data['allowed_users'] = array();
    
    $this->load->model('sale/customer');
    
    foreach ($allowed_users as $user_id) {
			$user_info = $this->model_sale_customer->getCustomer($user_id);
 
			if ($user_info) {
				$data['allowed_users'][] = array(
					'user_id' => $user_info['customer_id'],
					'name' => $user_info['firstname']. " " . $user_info['lastname']
				);
			}
		}
    
    if (isset($this->request->post['denied_users'])) {
			$denied_users = $this->request->post['denied_users'];
		} elseif (isset($this->request->get['category_id'])) {
			$denied_users = $this->model_setting_rights->getDeniedUsers($this->request->get['category_id'],2); //2 is information_category type
		} else {
			$denied_users = array();
		}
    
    $data['denied_users'] = array();
    
    foreach ($denied_users as $user_id) {
			$user_info = $this->model_sale_customer->getCustomer($user_id);
 
			if ($user_info) {
				$data['denied_users'][] = array(
					'user_id' => $user_info['customer_id'],
					'name' => $user_info['firstname']. " " . $user_info['lastname']
				);
			}
		}
    
    $data['sorts'] = array();

			$data['sorts'][] = array(
				'text'  => $this->language->get('text_date_desc'),
				'value' => 'i.date_added-DESC'
			);
      
      $data['sorts'][] = array(
				'text'  => $this->language->get('text_date_asc'),
				'value' => 'i.date_added-ASC'
			);
      
      $data['sorts'][] = array(
				'text'  => $this->language->get('text_name_asc'),
				'value' => 'id.title-ASC'
			);

			$data['sorts'][] = array(
				'text'  => $this->language->get('text_name_desc'),
				'value' => 'id.title-DESC'
			);
      
      $data['sorts'][] = array(
				'text'  => $this->language->get('text_csort_asc'),
				'value' => 'i.sort_order-ASC'
			);
      
    if (isset($this->request->post['default_sort_order'])) {
			$data['default_sort_order'] = $this->request->post['default_sort_order'];
		} elseif (!empty($category_info)) {
			$data['default_sort_order'] = $category_info['default_sort_order'];
		} else {
			$data['default_sort_order'] = 'i.date_added-DESC';
		}

		$data['header'] = $this->load->controller('common/header');
		$data['column_left'] = $this->load->controller('common/column_left');
		$data['footer'] = $this->load->controller('common/footer');

		$this->response->setOutput($this->load->view('catalog/information_category_form.tpl', $data));
	}

	protected function validateForm() {
		if (!$this->user->hasPermission('modify', 'catalog/information_category')) {
			$this->error['warning'] = $this->language->get('error_permission');
		}

		foreach ($this->request->post['category_description'] as $language_id => $value) {
			if ((utf8_strlen($value['name']) < 2) || (utf8_strlen($value['name']) > 255)) {
				$this->error['name'][$language_id] = $this->language->get('error_name');
			}

			if ((utf8_strlen($value['meta_title']) < 3) || (utf8_strlen($value['meta_title']) > 255)) {
				$this->error['meta_title'][$language_id] = $this->language->get('error_meta_title');
			}
		}
    
    if (utf8_strlen($this->request->post['keyword']) > 0) {
			$this->load->model('catalog/url_alias');

			$url_alias_info = $this->model_catalog_url_alias->getUrlAlias($this->request->post['keyword']);
		
			if ($url_alias_info && isset($this->request->get['category_id']) && $url_alias_info['query'] != 'information_category_id=' . $this->request->get['category_id']) {
				$this->error['keyword'] = sprintf($this->language->get('error_keyword'));
			}

			if ($url_alias_info && !isset($this->request->get['category_id'])) {
				$this->error['keyword'] = sprintf($this->language->get('error_keyword'));
			}
			
		}
    
		if ($this->error && !isset($this->error['warning'])) {
			$this->error['warning'] = $this->language->get('error_warning');
		}

		return !$this->error;
	}

	protected function validateDelete() {
		if (!$this->user->hasPermission('modify', 'catalog/information_category')) {
			$this->error['warning'] = $this->language->get('error_permission');
		}

		return !$this->error;
	}

	protected function validateRepair() {
		if (!$this->user->hasPermission('modify', 'catalog/information_category')) {
			$this->error['warning'] = $this->language->get('error_permission');
		}

		return !$this->error;
	}

	public function autocomplete() {
		$json = array();

		if (isset($this->request->get['filter_name'])) {
			$this->load->model('catalog/information_category');

			$filter_data = array(
				'filter_name' => $this->request->get['filter_name'],
				'start'       => 0,
				'limit'       => 5
			);

			$results = $this->model_catalog_information_category->getCategories($filter_data);

			foreach ($results as $result) {
				$json[] = array(
					'category_id' => $result['category_id'],
					'name'        => strip_tags(html_entity_decode($result['name'], ENT_QUOTES, 'UTF-8'))
				);
			}
		}

		$sort_order = array();

		foreach ($json as $key => $value) {
			$sort_order[$key] = $value['name'];
		}

		array_multisort($sort_order, SORT_ASC, $json);

		$this->response->addHeader('Content-Type: application/json');
		$this->response->setOutput(json_encode($json));
	}
}